@@ -9,6 +9,7 @@ from jarvis.core.specie import get_node_attributes
 import warnings
 from typing import List, Tuple
 from jarvis.core.atoms import Atoms
+from collections import defaultdict
 
 try:
     import torch
@@ -54,26 +55,54 @@ class Graph(object):
 
     @staticmethod
     def atom_dgl_multigraph(
-        atoms=None, cutoff=8.0, max_neighbors=12, atom_features="cgcnn"
+        atoms=None,
+        cutoff=8.0,
+        max_neighbors=12,
+        atom_features="cgcnn",
+        enforce_undirected=False,
+        max_attempts=3,
+        id=None,
     ):
         """Obtain a DGLGraph for Atoms object."""
         all_neighbors = atoms.get_all_neighbors(r=cutoff)
         # if a site has too few neighbors, increase the cutoff radius
         min_nbrs = min(len(neighborlist) for neighborlist in all_neighbors)
-        if min_nbrs < max_neighbors:
+        # print('min_nbrs,max_neighbors=',min_nbrs,max_neighbors)
+        attempt = 0
+        while min_nbrs < max_neighbors:
+            print("extending cutoff radius!", attempt, cutoff, id)
             lat = atoms.lattice
             r_cut = max(cutoff, lat.a, lat.b, lat.c)
-            return Graph.atom_dgl_multigraph(
-                atoms, r_cut, max_neighbors, atom_features
-            )
+            attempt += 1
+            if attempt >= max_attempts:
+                atoms = atoms.make_supercell([2, 2, 2])
+                print(
+                    "Making supercell, exceeded,attempts",
+                    max_attempts,
+                    "cutoff",
+                    r_cut,
+                    id,
+                )
+            cutoff = r_cut
+            all_neighbors = atoms.get_all_neighbors(r=cutoff)
+            min_nbrs = min(len(neighborlist) for neighborlist in all_neighbors)
+            # return Graph.atom_dgl_multigraph(
+            #    atoms, r_cut, max_neighbors, atom_features
+            # )
 
         # build up edge list
-        # NOTE: currently there's no guarantee
-        # that this creates undirected graphs
-        # An undirected solution would build the full edge
-        # list where nodes are
-        # keyed by (index, image), and ensure
-        # each edge has a complementary edge
+        # Currently there's no guarantee that this creates undirected graphs
+        # An undirected solution would build the full edge list where nodes are
+        # keyed by (index,image), and ensure each edge has a complementary edge
+
+        # indeed,JVASP-59628 is an example of a calculation where this produces
+        # a graph where one site has no incident edges!
+
+        # build an edge dictionary u -> v
+        # so later we can run through the dictionary
+        # and remove all pairs of edges
+        # so what's left is the odd ones out
+        edges = defaultdict(list)
 
         u, v, r = [], [], []
         for site_idx, neighborlist in enumerate(all_neighbors):
@@ -83,18 +112,37 @@ class Graph(object):
 
             ids = np.array([nbr[1] for nbr in neighborlist])
             distances = np.array([nbr[2] for nbr in neighborlist])
+            c = np.array([nbr[3] for nbr in neighborlist])
 
             # find the distance to the k-th nearest neighbor
             max_dist = distances[max_neighbors - 1]
 
             # keep all edges out to the neighbor shell of the k-th neighbor
             ids = ids[distances <= max_dist]
+            c = c[distances <= max_dist]
             distances = distances[distances <= max_dist]
 
             u.append([site_idx] * len(ids))
             v.append(ids)
             r.append(distances)
 
+            # keep track of cell-resolved edges
+            # to enforce undirected graph construction
+            for dst, cell_id in zip(ids, c):
+                u_key = f"{site_idx}-(0.0, 0.0, 0.0)"
+                v_key = f"{dst}-{tuple(cell_id)}"
+                edge_key = tuple(sorted((u_key, v_key)))
+                edges[edge_key].append((site_idx, dst))
+
+        if enforce_undirected:
+            # add complementary edges to unpaired edges
+            for edge_pair in edges.values():
+                if len(edge_pair) == 1:
+                    src, dst = edge_pair[0]
+                    u.append(dst)  # swap the order!
+                    v.append(src)
+                    r.append(atoms.raw_distance_matrix[src, dst])
+
         u = torch.tensor(np.hstack(u))
         v = torch.tensor(np.hstack(v))
         r = torch.tensor(np.hstack(r)).type(torch.get_default_dtype())
@@ -334,33 +382,38 @@ class StructureDataset(torch.utils.data.Dataset):
         self,
         structures,
         targets,
+        ids=None,
         cutoff=8.0,
         maxrows=np.inf,
         atom_features="atomic_number",
         transform=None,
+        enforce_undirected=False,
         max_neighbors=12,
     ):
         """Initialize the class."""
         self.graphs = []
         self.labels = []
+        self.ids = []
 
-        for idx, (structure, target) in enumerate(
-            tqdm(zip(structures, targets))
+        for idx, (structure, target, id) in enumerate(
+            tqdm(zip(structures, targets, ids))
         ):
 
             if idx >= maxrows:
                 break
-
             a = Atoms.from_dict(structure)
             g = Graph.atom_dgl_multigraph(
                 a,
                 atom_features=atom_features,
+                enforce_undirected=enforce_undirected,
                 cutoff=cutoff,
                 max_neighbors=max_neighbors,
+                id=id,
             )
 
             self.graphs.append(g)
             self.labels.append(target)
+            self.ids.append(id)
 
         self.labels = torch.tensor(self.labels).type(torch.get_default_dtype())
         self.transform = transform
