@@ -46,22 +46,17 @@ poscar_path = os.path.join(
     "POSCAR",
 )
 
-cif_example = os.path.join(
-    os.path.dirname(__file__),
-    "1000052.cif",
-)
-cif_example2 = os.path.join(
-    os.path.dirname(__file__),
-    "Bacomp.cif",
-)
-cif_example3 = os.path.join(
-    os.path.dirname(__file__),
-    "mock.cif",
-)
+cif_example = os.path.join(os.path.dirname(__file__), "1000052.cif",)
+cif_example2 = os.path.join(os.path.dirname(__file__), "Bacomp.cif",)
+cif_example3 = os.path.join(os.path.dirname(__file__), "mock.cif",)
+
+
 def test_from_cif():
-    a=Atoms.from_cif(cif_example)
-    a=Atoms.from_cif(cif_example2)
-    a=Atoms.from_cif(cif_example3)
+    a = Atoms.from_cif(cif_example)
+    a = Atoms.from_cif(cif_example2)
+    a = Atoms.from_cif(cif_example3)
+
+
 def test_basic_atoms():
 
     box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
@@ -96,7 +91,7 @@ def test_basic_atoms():
     assert round(prim.raw_distance_matrix[0][1], 2) == round(
         4.42386329832851, 2
     )
-    asee=Si.ase_converter()
+    asee = Si.ase_converter()
     print(prim.raw_angle_matrix)
     d = Si.to_dict()
     new_at = Atoms.from_dict(d)
@@ -106,13 +101,14 @@ def test_basic_atoms():
         coords=d["coords"],
         elements=d["elements"],
     ).density
-    Si_xyz=Si.get_xyz_string
+    Si_xyz = Si.get_xyz_string
     Si.write_xyz(filename="atoms.xyz")
-    tmp=Atoms.from_xyz(filename="atoms.xyz")
-    cmd='rm atoms.xyz'
+    tmp = Atoms.from_xyz(filename="atoms.xyz")
+    cmd = "rm atoms.xyz"
     os.system(cmd)
     Si.center_around_origin()
     # print ('scell_nat', Si_2)
+    nb = Si.get_all_neighbors(5)
     assert (
         round(Si.volume, 2),
         Si.atomic_numbers,
@@ -160,7 +156,7 @@ def test_basic_atoms():
     )
     cc = Si.center()
     cc = Si.center(axis=[0, 0, 1])
-    cc = Si.center(about=[.5,.5,.5])
+    cc = Si.center(about=[0.5, 0.5, 0.5])
 
     m1 = Atoms.from_dict(get_jid_data("JVASP-6640")["atoms"])
     assert m1.check_polar == True
@@ -173,7 +169,7 @@ def test_basic_atoms():
     assert m1.lattice_mat[2][2] == 36.158933360000006
     filename = "atoms.cif"
     m1.write_cif(filename)
-    a=Atoms.from_cif(filename)
+    a = Atoms.from_cif(filename)
     filename = "POSCAR"
     m1.write_poscar(filename)
     m2 = Atoms.from_poscar(filename)
